@@ -6,23 +6,22 @@ Note:
 
 import argparse
 import logging
-from typing import List
 
 import moe
 import moe.cli
-from moe import query
-from moe.config import Config
+from moe import config
+from moe.query import QueryError, query
 
-__all__: List[str] = []
+__all__: list[str] = []
 
-log = logging.getLogger("moe.list")
+log = logging.getLogger("moe.cli.list")
 
 
 @moe.hookimpl
-def plugin_registration(config: Config):
+def plugin_registration():
     """Depend on the cli plugin."""
-    if not config.plugin_manager.has_plugin("cli"):
-        config.plugin_manager.set_blocked("list")
+    if not config.CONFIG.pm.has_plugin("cli"):
+        config.CONFIG.pm.set_blocked("list")
         log.warning("The 'list' plugin requires the 'cli' plugin to be enabled.")
 
 
@@ -45,19 +44,23 @@ def add_command(cmd_parsers: argparse._SubParsersAction):
     ls_parser.set_defaults(func=_parse_args)
 
 
-def _parse_args(config: Config, args: argparse.Namespace):
+def _parse_args(args: argparse.Namespace):
     """Parses the given commandline arguments.
 
     Args:
-        config: Configuration in use.
         args: Commandline arguments to parse.
 
     Raises:
-        SystemExit: Query returned no tracks.
+        SystemExit: Invalid query or no items found.
     """
-    items = query.query(args.query, query_type=args.query_type)
+    try:
+        items = query(args.query, query_type=args.query_type)
+    except QueryError as err:
+        log.error(err)
+        raise SystemExit(1) from err
 
     if not items:
+        log.error("No items found to list.")
         raise SystemExit(1)
 
     for item in items:
